@@ -77,7 +77,7 @@ END {
     if (!$NO_ENDING) {
 	if (defined $planned && $planned != $ran) {
 	    _print_stderr
-		"# Looks like you planned $planned tests but ran $ran.\n";
+		"# It looks as though you planned $planned tests but ran $ran.\n";
 	} elsif ($noplan) {
 	    _print "1..$ran\n";
 	}
